@@ -743,13 +743,14 @@ fill_current_data(xmlNode *root_node, GHashTable *current_weather, GHashTable *d
                                                                                                 g_strdup("Full"));
                                                     }
                                                     if (strstr(temp_xml_string,"vax1")){
-                                                        if (!strncmp(temp_xml_string,"moon1",5))
+                                                        if (!strncmp(temp_xml_string,"moon0",5))
                                                             g_hash_table_insert(current_weather, "moon_phase", 
-                                                                                                g_strdup("New"));
-                                                        if (!strncmp(temp_xml_string,"moon2",5)||!strncmp(temp_xml_string,"moon3",5))
+                                                                                                g_strdup("Waxing Crescent"));
+                                                        if (!strncmp(temp_xml_string,"moon1",5)||!strncmp(temp_xml_string,"moon2",5)||
+                                                            !strncmp(temp_xml_string,"moon3",5))
                                                             g_hash_table_insert(current_weather, "moon_phase", 
                                                                                                 g_strdup("Waning Crescent"));
-                                                        if (!strncmp(temp_xml_string,"moon3",5)||!strncmp(temp_xml_string,"moon4",5))
+                                                        if (!strncmp(temp_xml_string,"moon4",5))
                                                             g_hash_table_insert(current_weather, "moon_phase", 
                                                                                                 g_strdup("Last Quarter"));
                                                         if (!strncmp(temp_xml_string,"moon5",5)||!strncmp(temp_xml_string,"moon6",5))
